---

slug: /large-object-and-text-type-overview
---

# Overview of large object and text types

seekdb supports the `BLOB` and `TEXT` types for large objects and text.

The following table describes the large object and text types supported by seekdb in the current version and related information.

|      Type      | Length |   Maximum Storage Length (Bytes)   |    Character Set    |
|--------------|----|----------------|-----------|
| `TINYBLOB`   | Variable | 255          | `BINARY`  |
| `BLOB`       | Variable | 65535        | `BINARY`  |
| `MEDIUMBLOB` | Variable | 16777215     | `BINARY`  |
| `LONGBLOB`   | Variable | 536870910    | `BINARY`  |
| `TINYTEXT`   | Variable | 256          | `UTF8MB4` |
| `TEXT`       | Variable | 65535        | `UTF8MB4` |
| `MEDIUMTEXT` | Variable | 16777215     | `UTF8MB4` |
| `LONGTEXT`   | Variable | 536870910    | `UTF8MB4` |
| `STRING`     | Variable | 16777216     | `UTF8MB4` |

In most cases, you can treat a `BLOB` column as a `VARBINARY` column and a `TEXT` column as a `VARCHAR` column. `BLOB` and `TEXT`/`STRING` differ from `VARBINARY` and `VARCHAR` in the following aspects:

* You must specify the prefix length for an index on a `BLOB` or `TEXT` column. For `CHAR` and `VARCHAR`, the prefix length is optional.

* `BLOB` and `TEXT`/`STRING` columns cannot have `DEFAULT` values.